@@ -1,4 +1,4 @@
-from devops_config import devops_config
+from .devops_config import devops_config
 from azure.devops.connection import Connection
 from msrest.authentication import BasicAuthentication
 
