@@ -5,7 +5,7 @@ from .repos import devops_ref
 from .policy_types import policy_type
 
 
-class policy_builder():
+class policy_builder:
     def __init__(self, poltype, project, devopsref, policycontent, scope='Exact', isblocking=False):
         """ build policy object json from setting and objects
 
